@@ -251,5 +251,5 @@ def compute_relevancy_score_for_content(sentence: spacy.tokens.span.Span, brand:
     children = [x for x in children if x != []]
     in_conjuntion = [x for x in in_conjuntion if x != []]
     if include_ancestor_children_dep:
-        return deps_brand, relevancy_score, idx_brand, pos_brand, ancestor, children, in_conjuntion
+        return deps_brand, relevancy_score, pos_brand, idx_brand, ancestor, children, in_conjuntion
     return relevancy_score
